# /bin/sh !

CC=$1
INSTALL_DIR=`which $CC`

INSTALL_DIR=`dirname $INSTALL_DIR`

BIN_PATH=$INSTALL_DIR
CURRENT_DIR=`pwd`
cd $INSTALL_DIR
cd ../
INSTALL_DIR=`pwd `
cd $CURRENT_DIR


  ac_prog_version=`$CC -v 2>&1 | sed -n 's/^.*version \([egcygnustpi-]*[0-9.]*\).*$/\1/p'`
  case $ac_prog_version in
    '') ac_prog_version="v. ?.??, bad"; ac_verc_fail=yes;;
    3.4.3)
        ac_verc_fail=no;;
     *) ac_verc_fail=yes;;

  esac

  ac_is_softfloat_version=`$CC -v 2>&1 | grep with-float=soft -c`
  
  if [ "$ac_is_softfloat_version" != "1" ];
    then
    echo "please set PATH variable to point to your softfloat version of GCC-3.4.3 !"
    echo "please also set CROSS variable to a suitable command prefix like 'arm-elf' or 'arm-linux' "
    echo "this version cannot be used with crunch-softfloat"
    exit 1;
  fi


echo "GCC version different from GCC-3.4.3 ? " $ac_verc_fail
echo "gcc installed in: "$INSTALL_DIR
echo "gcc bin directory is: "$BIN_PATH


get_libgcc_path()
{
    find $INSTALL_DIR -path "*/3.4.3/libgcc.a"
}


LIBGCC_PATH=$(get_libgcc_path)

LIBGCC_PATH=`dirname $LIBGCC_PATH`

if [ "$LIBGCC_PATH" == "" ];
    then
    echo "couldn't locate gcc-3.4.3's libgcc.a !"
    exit 1;
fi

echo libgcc.a path found : $LIBGCC_PATH

if [ -e $LIBGCC_PATH/libgcc.a-nofloat ];
    then
	echo crunchlib support already installed !
	exit 1;
fi

mv $LIBGCC_PATH/libgcc.a $LIBGCC_PATH/libgcc.a-softfloat
cp libgcc.a-nofloat $LIBGCC_PATH
cp libfloat.a $LIBGCC_PATH
ln -s $LIBGCC_PATH/libgcc.a-softfloat $LIBGCC_PATH/libgcc.a

FILENAME=$BIN_PATH/arm-linux-chfloat

echo "#! /bin/bash" > $FILENAME
echo LIBGCC_PATH=$LIBGCC_PATH >> $FILENAME

echo '

rm $LIBGCC_PATH/libgcc.a

case "$1" in
  crunch)
    echo "compiling using crunch library"
    ln -s $LIBGCC_PATH/libgcc.a-nofloat $LIBGCC_PATH/libgcc.a
    ;;

  softfloat)
    echo "compiling using softfloat library"
    ln -s $LIBGCC_PATH/libgcc.a-softfloat $LIBGCC_PATH/libgcc.a
    ;;

  *)
    echo "Usage: arm-linux-chfloat {crunch|softfloat}"
    exit 1
    ;;
esac

' >> $FILENAME

chmod 733 $FILENAME

echo "crunchlib support installed successfully"
